;; Generated package description from urgrep.el  -*- no-byte-compile: t -*-
(define-package "urgrep" "0.3.1snapshot0.20231221.164910" "Universal recursive grep" '((emacs "27.1") (compat "29.1.0.1") (project "0.3.0")) :commit "efef42bfc15a9acc85cf55da53538e65b1611d7d" :keywords '("grep" "search") :url "https://github.com/jimporter/urgrep")
